summaryrefslogtreecommitdiff
path: root/libavcodec/vc1_parser.c
diff options
context:
space:
mode:
Diffstat (limited to 'libavcodec/vc1_parser.c')
-rw-r--r--libavcodec/vc1_parser.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/libavcodec/vc1_parser.c b/libavcodec/vc1_parser.c
index da8ba87b7c..27ff1bdaa3 100644
--- a/libavcodec/vc1_parser.c
+++ b/libavcodec/vc1_parser.c
@@ -67,9 +67,9 @@ static void vc1_extract_headers(AVCodecParserContext *s, AVCodecContext *avctx,
else
vc1_parse_frame_header_adv(&vpc->v, &gb);
- /* keep FF_BI_TYPE internal to VC1 */
- if (vpc->v.s.pict_type == FF_BI_TYPE)
- s->pict_type = FF_B_TYPE;
+ /* keep AV_PICTURE_TYPE_BI internal to VC1 */
+ if (vpc->v.s.pict_type == AV_PICTURE_TYPE_BI)
+ s->pict_type = AV_PICTURE_TYPE_B;
else
s->pict_type = vpc->v.s.pict_type;